@@ -1,5 +1,6 @@
-/* Copyright (C) 2000, 2001 Stefan Buehler <sbuehler@uni-bremen.de>,
-                            Axel von Engeln <engeln@uni-bremen.de>
+/* Copyright (C) 2000-2008
+   Stefan Buehler <sbuehler@ltu.se>,
+   Axel von Engeln <engeln@uni-bremen.de>
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -24,8 +25,11 @@
   else. You can add new records here if you want to extend the
   capability of ARTS.
 
+  This is the file from arts-1-0, back-ported to arts-1-1.
+
   \author Stefan Buehler, Axel von Engeln
-  \date 2000-08-10 */
+  \date 2000-08-10 
+*/
 
 #include "arts.h"
 #include "make_array.h"
@@ -87,7 +91,7 @@ Array<SpeciesRecord> species_data;
        <td> 2: <td> jpl isotopic ratio, taken from the documentation coming
                     along with the catalogue. latest catalogue version
                     extracted 27.07.00, can be found at
-                    /pool/lookup/jpl/cat7_00/doc/d<tag_nr>.cat 
+                    /pool/lookup/jpl/cat7_00/doc/d\<tag_nr\>.cat 
        <tr>
        <td> 3: <td> jpl isotopic ratio is multiplied with the maximum isotopic ratio
                     of this species found in hitran. is only performed when
@@ -95,12 +99,12 @@ Array<SpeciesRecord> species_data;
        </table>
 
   <dt> Mass: 
-//  <dd> Rounded atomic weight. (SAB: From looking at the table in forward_4_96,
-//       glob_def.c, the difference between the actual mass and the mass
-//       simply estimated from the Atom number is only 0.001. This seems
-//       not worth the trouble. Anyway, the field for the mass is
-//       there. Should anybody feel like adding the true numbers, just go
-//       ahead.)
+  <!-- <dd> Rounded atomic weight. (SAB: From looking at the table in forward_4_96,
+       glob_def.c, the difference between the actual mass and the mass
+       simply estimated from the Atom number is only 0.001. This seems
+       not worth the trouble. Anyway, the field for the mass is
+       there. Should anybody feel like adding the true numbers, just go
+       ahead.) -->
   <dd> mass as given in file MOLPARAM.TXT of HITRAN2000. 
        If tag is not present in HITRAN, the rounded value is stated. 
        Note that the mass is given in units of [g/mol].
@@ -138,8 +142,6 @@ void define_species_data()
 
 void define_basic_species_data()
 {
-  extern Array<SpeciesRecord> species_data;
-
   // Initialize to zero, just in case:
   species_data.resize(0);
 
@@ -299,16 +301,20 @@ void define_basic_species_data()
   //       - CH4 is in official mytran list (6), but does not 
   //         seem to be included for calculation, as given
   //         by table tag_table in file glob_def.c
+  // 2009-6-10 SAB Added Isotope 312, which is new in HITRAN08.
+  //           Parameters from HITRAN file molparam.txt.
+  //           Still commented out, due to missing partition function data.
   species_data.push_back
     ( SpeciesRecord
       ( NAME("CH4"),
         DEGFR(3),
         ISOTOPES
-        (//  Name,      Isotopic Ratio, Mass,   MY-tag, HI-tag, JPL-tag
-         //             |               |       |       |       |
+        (//  Name,       Isotopic Ratio,  Mass,         MY-tag, HI-tag, JPL-tag
+         //              |                |             |       |       |
          REC("211"      ,.988274E+00     ,16.031300    ,-1     ,61     ,TAGS()),
          REC("311"      ,1.11031E-02     ,17.034655    ,-1     ,62     ,TAGS()),
          REC("212"      ,6.15751E-04     ,17.037475    ,-1     ,63     ,TAGS(17003))
+//         REC("312"      ,6.91785E-06     ,18.040830      ,-1     ,64     ,TAGS())
          ) ) );
 
   // O2
